@@ -3,7 +3,7 @@ package HTML::DOM::Implementation;
 use strict;
 use warnings;
 
-our $VERSION = '0.049';
+our $VERSION = '0.050';
 
 our $it = bless do{\my$x};
 
@@ -50,7 +50,7 @@ HTML::DOM::Implementation - HTML::DOM's 'DOMImplementation' object
 =head1 DESCRIPTION
 
 This singleton class provides L<HTML::DOM>'s 'DOMImplementation' object.
-There is no constructor. The object itself is accessible as
+There is no constructor.  The object itself is accessible as
 C<$HTML::DOM::Implementation::it> or C<< HTML::DOM->implementation >>.
 
 =head1 THE ONLY METHOD
@@ -58,8 +58,9 @@ C<$HTML::DOM::Implementation::it> or C<< HTML::DOM->implementation >>.
 =head2 $implementation->hasFeature( $name, $version )
 
 This returns true or false depending on whether the feature is supported.
-C<$name> is case-tolerant. C<$version> is optional. The supported features
-are listed under L<HTML::DOM/DESCRIPTION>. If C<$version> is '1.0', this 
+C<$name> is case-tolerant.  C<$version> is optional.  The supported
+features
+are listed under L<HTML::DOM/DESCRIPTION>.  If C<$version> is '1.0', this 
 method only returns true for 'Core' and 'HTML'.
 
 =head1 SEE ALSO
